=============
Release Notes
=============

0.0.9 (2022-10-??)
------------------

- Added a frequency-shift function ``pulsarbat.freq_shift`` (:pr:`52`)
- Added a snippet function ``pulsarbat.snippet`` (:pr:`54`)
- ``pulsarbat.time_shift`` can now support multiple shifts (:pr:`58`)
